==> d1-pac-0.0.5.crate: d1-pac-0.0.5/src/spi0/spi_rxd.rs <==
#[doc = "Register `SPI_RXD` reader"]
pub struct R(crate::R<SPI_RXD_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_RXD_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_RXD_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_RXD_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_RXD` writer"]
pub struct W(crate::W<SPI_RXD_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_RXD_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_RXD_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_RXD_SPEC>) -> Self {
        W(writer)
    }
}
impl W {
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SPI RX Data Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_rxd](index.html) module"]
pub struct SPI_RXD_SPEC;
impl crate::RegisterSpec for SPI_RXD_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_rxd::R](R) reader structure"]
impl crate::Readable for SPI_RXD_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_rxd::W](W) writer structure"]
impl crate::Writable for SPI_RXD_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_RXD to value 0"]
impl crate::Resettable for SPI_RXD_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> d1-pac-0.0.6.crate: d1-pac-0.0.6/src/spi0/spi_rxd.rs <==
#[doc = "Register `SPI_RXD` reader"]
pub struct R(crate::R<SPI_RXD_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_RXD_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_RXD_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_RXD_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_RXD` writer"]
pub struct W(crate::W<SPI_RXD_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_RXD_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_RXD_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_RXD_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `rdata` reader - Receive Data"]
pub struct RDATA_R(crate::FieldReader<u32, u32>);
impl RDATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        RDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for RDATA_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `rdata` writer - Receive Data"]
pub struct RDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> RDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Receive Data"]
    #[inline(always)]
    pub fn rdata(&self) -> RDATA_R {
        RDATA_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Receive Data"]
    #[inline(always)]
    pub fn rdata(&mut self) -> RDATA_W {
        RDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SPI RX Data Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_rxd](index.html) module"]
pub struct SPI_RXD_SPEC;
impl crate::RegisterSpec for SPI_RXD_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_rxd::R](R) reader structure"]
impl crate::Readable for SPI_RXD_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_rxd::W](W) writer structure"]
impl crate::Writable for SPI_RXD_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_RXD to value 0"]
impl crate::Resettable for SPI_RXD_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
